#
# Configuration file for using the XML library in GNOME applications
#
XML2_LIBDIR="-LFIXMESTAGINGDIRHOST/usr/lib"
XML2_LIBS="-lxml2 -LFIXMESTAGINGDIRHOST/usr/lib/pkgconfig/../../../usr/lib -lz     -lm "
XML2_INCLUDEDIR="-IFIXMESTAGINGDIRHOST/usr/include/libxml2"
MODULE_VERSION="xml2-2.9.14"

